@@ -21,10 +21,10 @@
 (require 'map)
 (require 'subr-x)
 (require 'cl-lib)
-(require 'el-job-child)
-(require 'el-job)
+(require 'el-job-old-child)
+(require 'el-job-old)
 
-(ert-deftest el-job--split-optimally ()
+(ert-deftest el-job-old--split-optimally ()
   ;; All benchmarks at zero
   (let* ((plist (cl-loop for i below 50
                          nconc (list (format "file-%d.org" i)
@@ -33,12 +33,12 @@
          (big-table (map-into (take 100 plist) '(hash-table :test equal)))
          (tiny-table (map-into (take 10 plist) '(hash-table :test equal)))
          (empty-table (make-hash-table :test #'equal)))
-    (should (>= 15 (length (el-job--split-optimally items 15 big-table))))
-    (should (>= 15 (length (el-job--split-optimally items 15 tiny-table))))
-    (should (= 15 (length (el-job--split-optimally items 15 empty-table))))
-    (should (= 5 (length (el-job--split-optimally (take 5 items) 15 big-table))))
-    (should (= 5 (length (el-job--split-optimally (take 5 items) 15 tiny-table))))
-    (should (= 5 (length (el-job--split-optimally (take 5 items) 15 empty-table)))))
+    (should (>= 15 (length (el-job-old--split-optimally items 15 big-table))))
+    (should (>= 15 (length (el-job-old--split-optimally items 15 tiny-table))))
+    (should (= 15 (length (el-job-old--split-optimally items 15 empty-table))))
+    (should (= 5 (length (el-job-old--split-optimally (take 5 items) 15 big-table))))
+    (should (= 5 (length (el-job-old--split-optimally (take 5 items) 15 tiny-table))))
+    (should (= 5 (length (el-job-old--split-optimally (take 5 items) 15 empty-table)))))
 
   ;; All benchmarks at random nonzero duration (up to 2.0s)
   (let* ((plist (cl-loop for i below 50
@@ -48,22 +48,22 @@
          (big-table (map-into (take 100 plist) '(hash-table :test equal)))
          (tiny-table (map-into (take 10 plist) '(hash-table :test equal)))
          (empty-table (make-hash-table :test #'equal)))
-    (should (>= 15 (length (el-job--split-optimally items 15 big-table))))
-    (should (>= 15 (length (el-job--split-optimally items 15 tiny-table))))
-    (should (= 15 (length (el-job--split-optimally items 15 empty-table))))
-    (should (= 5 (length (el-job--split-optimally (take 5 items) 15 big-table))))
-    (should (= 5 (length (el-job--split-optimally (take 5 items) 15 tiny-table))))
-    (should (= 5 (length (el-job--split-optimally (take 5 items) 15 empty-table))))))
+    (should (>= 15 (length (el-job-old--split-optimally items 15 big-table))))
+    (should (>= 15 (length (el-job-old--split-optimally items 15 tiny-table))))
+    (should (= 15 (length (el-job-old--split-optimally items 15 empty-table))))
+    (should (= 5 (length (el-job-old--split-optimally (take 5 items) 15 big-table))))
+    (should (= 5 (length (el-job-old--split-optimally (take 5 items) 15 tiny-table))))
+    (should (= 5 (length (el-job-old--split-optimally (take 5 items) 15 empty-table))))))
 
-(ert-deftest el-job--ensure-compiled-lib ()
+(ert-deftest el-job-old--ensure-compiled-lib ()
   (when (and (require 'comp nil t)
              (native-comp-available-p)
              (boundp 'comp-async-compilations)
              (hash-table-p comp-async-compilations)
              (fboundp #'comp-lookup-eln))
     (let (skip-test)
-      (let ((loaded (el-job--locate-lib-in-load-history
-                     'el-job-child)))
+      (let ((loaded (el-job-old--locate-lib-in-load-history
+                     'el-job-old-child)))
         (when (string-suffix-p ".el" loaded)
           (setq loaded (comp-lookup-eln loaded)))
         (when (and loaded (string-suffix-p ".eln" loaded))
@@ -71,15 +71,15 @@
               (delete-file loaded)
             (file-error (setq skip-test t)))))
       (unless skip-test
-        (load (locate-library "el-job-child.el"))
-        (should (string-suffix-p ".el" (el-job--locate-lib-in-load-history
-                                        'el-job-child)))
-        (should (string-suffix-p ".elc" (el-job--ensure-compiled-lib
-                                         'el-job-child)))
+        (load (locate-library "el-job-old-child.el"))
+        (should (string-suffix-p ".el" (el-job-old--locate-lib-in-load-history
+                                        'el-job-old-child)))
+        (should (string-suffix-p ".elc" (el-job-old--ensure-compiled-lib
+                                         'el-job-old-child)))
         (when (let ((procs (hash-table-values comp-async-compilations)))
-                (not (el-job--sit-until-not
+                (not (el-job-old--sit-until-not
                       (cl-some #'process-live-p procs) 10)))
-          (should (string-suffix-p ".eln" (el-job--ensure-compiled-lib
-                                           'el-job-child))))))))
+          (should (string-suffix-p ".eln" (el-job-old--ensure-compiled-lib
+                                           'el-job-old-child))))))))
 
 ;;; el-job-test.el ends here
